@@ -19,7 +19,7 @@ sub _PARENT_INDEX             { return -1 }
 sub _EXCEL_COLUMN_RADIX       { return 26 }
 sub _BUFFER_SIZE              { return 4096 }
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -241,7 +241,8 @@ sub _handle_workbook_type_zips {
         $self->{zip}       = $zip;
         $self->{row_index} = 0;
         my $content = $worksheet->contents();
-        my $cells = $self->_xlsx_cells( $content, $shared_strings, $worksheet_path );
+        my $cells =
+          $self->_xlsx_cells( $content, $shared_strings, $worksheet_path );
         if ( defined $cells ) {
             $self->{cells} = $cells;
             return 1;
@@ -443,9 +444,8 @@ sub _ksp_cells {
     my $xml               = XML::Parser->new(
         Handlers => {
             Entity => sub {
-                die(
-"XML Entities have been detected and rejected in the XML, due to security concerns\n"
-                );
+                die
+"XML Entities have been detected and rejected in the XML, due to security concerns\n";
             },
             Start => sub {
                 my ( $expat, $element_name, %element_parameters ) = @_;
@@ -508,9 +508,8 @@ sub _ods_cells {
     my $xml = XML::Parser->new(
         Handlers => {
             Entity => sub {
-                die(
-"XML Entities have been detected and rejected in the XML, due to security concerns\n"
-                );
+                die
+"XML Entities have been detected and rejected in the XML, due to security concerns\n";
             },
             Start => sub {
                 my ( $expat, $element_name, %element_parameters ) = @_;
@@ -606,9 +605,8 @@ sub _gnumeric_cells {
     my $xml = XML::Parser->new(
         Handlers => {
             Entity => sub {
-                die(
-"XML Entities have been detected and rejected in the XML, due to security concerns\n"
-                );
+                die
+"XML Entities have been detected and rejected in the XML, due to security concerns\n";
             },
             Start => sub {
                 my ( $expat, $element_name, %element_parameters ) = @_;
@@ -663,7 +661,8 @@ sub _gnumeric_cells {
     eval { $xml->parse($gnumeric_content); } or do {
         chomp $EVAL_ERROR;
         $EVAL_ERROR =~ s/^\s*//smx;
-        $self->{_ERROR_DIAG} = "XML - Invalid XML in gzipped gnumeric file:$EVAL_ERROR";
+        $self->{_ERROR_DIAG} =
+          "XML - Invalid XML in gzipped gnumeric file:$EVAL_ERROR";
         return;
     };
     if ( defined $cells ) {
@@ -694,9 +693,8 @@ sub _xlsx_shared_strings {
     my $xml            = XML::Parser->new(
         Handlers => {
             Entity => sub {
-                die(
-"XML Entities have been detected and rejected in the XML, due to security concerns\n"
-                );
+                die
+"XML Entities have been detected and rejected in the XML, due to security concerns\n";
             },
             Start => sub {
                 my ( $expat, $element_name, %element_parameters ) = @_;
@@ -735,7 +733,8 @@ sub _xlsx_shared_strings {
     eval { $xml->parse($shared_string_content); } or do {
         chomp $EVAL_ERROR;
         $EVAL_ERROR =~ s/^\s*//smx;
-        $self->{_ERROR_DIAG} = "XML - Invalid XML in sharedStrings.xml:$EVAL_ERROR";
+        $self->{_ERROR_DIAG} =
+          "XML - Invalid XML in sharedStrings.xml:$EVAL_ERROR";
         return;
     };
     return $shared_strings;
@@ -755,9 +754,8 @@ sub _xlsx_worksheet_path {
     my $xml = XML::Parser->new(
         Handlers => {
             Entity => sub {
-                die(
-"XML Entities have been detected and rejected in the XML, due to security concerns\n"
-                );
+                die
+"XML Entities have been detected and rejected in the XML, due to security concerns\n";
             },
             Start => sub {
                 my ( $expat, $element_name, %element_parameters ) = @_;
@@ -795,7 +793,8 @@ sub _xlsx_worksheet_path {
     eval { $xml->parse($content); } or do {
         chomp $EVAL_ERROR;
         $EVAL_ERROR =~ s/^\s*//smx;
-        $self->{_ERROR_DIAG} = "XML - Invalid XML in xl/workbook.xml:$EVAL_ERROR";
+        $self->{_ERROR_DIAG} =
+          "XML - Invalid XML in xl/workbook.xml:$EVAL_ERROR";
         return;
     };
     if ( !defined $worksheet_number ) {
@@ -821,9 +820,8 @@ sub _xlsx_cells {
     my $xml               = XML::Parser->new(
         Handlers => {
             Entity => sub {
-                die(
-"XML Entities have been detected and rejected in the XML, due to security concerns\n"
-                );
+                die
+"XML Entities have been detected and rejected in the XML, due to security concerns\n";
             },
             Start => sub {
                 my ( $expat, $element_name, %element_parameters ) = @_;
@@ -882,7 +880,8 @@ sub _xlsx_cells {
     );
     eval { $xml->parse($xlsx_content); } or do {
         chomp $EVAL_ERROR;
-        $self->{_ERROR_DIAG} = "XML - Invalid XML in $worksheet_path:$EVAL_ERROR";
+        $self->{_ERROR_DIAG} =
+          "XML - Invalid XML in $worksheet_path:$EVAL_ERROR";
         return;
     };
     return $cells;
@@ -897,7 +896,7 @@ Spreadsheet::CSV - Drop-in replacement for Text::CSV_XS with spreadsheet support
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
